# Comprehensive Benchmark Report

| Task             | Engine        | Total Time   |   Tool Calls |   Iterations |
|------------------|---------------|--------------|--------------|--------------|
| Simple Read      | clawagents_py | 8.23s        |            1 |            1 |
| Simple Read      | clawagents_ts | 6.18s        |            0 |            1 |
| OS Command       | clawagents_py | 9.13s        |            1 |            1 |
| OS Command       | clawagents_ts | 5.38s        |            1 |            1 |
| Multi-step Chain | clawagents_py | 7.75s        |            3 |            1 |
| Multi-step Chain | clawagents_ts | 13.61s       |            3 |            1 |
| Code Generation  | clawagents_py | 10.65s       |            3 |            1 |
| Code Generation  | clawagents_ts | 4.94s        |            0 |            1 |
